# django-syncpermissions

## Features
Sync permissions for specified apps, or all apps if none specified

## Use it
```bash
./manage.py sync_permissions
./manage.py sync_permissions appname
./manage.py sync_permissions appname1 appname2
```
